---
id: 20211122194827
title: Install MkDocs Zettelkasten
tags: [how-to, mkdocs, zettelkasten]
---

## Method 1: pip

This package is published in [Python Package Index aka PyPI](https://pypi.org/project/mkdocs-zettelkasten/), therefore you can install it simply by `pip`:

```bash
pip install mkdocs-zettelkasten
```

## Method 2: docker

Follow [Docker Hub repository buvis/mkdocs-git-sync](https://hub.docker.com/repository/docker/buvis/mkdocs-git-sync) instructions.

## Method 3: helm

Follow [buvis charts](https://charts.buvis.net) instructions.

---

web: [zettelkasten.de](https://zettelkasten.de)
web: [MkDocs](https://github.com/mkdocs/mkdocs/)
---
